class LicensesService1(object):

    default_url = 'http://licenses.opendefinition.org/1.0/all_formatted'

    def get_names(self):
        from pylons import config
        import urllib2
        import simplejson
        url = config.get('licenses_service_url', self.default_url)
        try:
            response = urllib2.urlopen(url)
            response_body = response.read()
        except Exception, inst:
            msg = "Couldn't connect to licenses service: %s" % inst
            raise Exception, msg
        try:
            license_names = simplejson.loads(response_body)
        except Exception, inst:
            msg = "Couldn't read response from licenses service: %s" % inst
            raise Exception, inst
        return [unicode(l) for l in license_names]


## For Licenses SoS v2.0.
class LicensesService2(object):

    default_group_url = 'http://licenses.opendefinition.org/2.0/all'

    def __init__(self, group_url=''):
        self.group_url = group_url or self.default_group_url

    def get_licenses(self):
        import urllib2
        import simplejson
        try:
            response = urllib2.urlopen(self.group_url)
            response_body = response.read()
        except Exception, inst:
            msg = "Couldn't connect to licenses service: %s" % inst
            raise Exception, msg
        try:
            licenses = simplejson.loads(response_body)
        except Exception, inst:
            msg = "Couldn't read response from licenses service: %s" % inst
            raise Exception, inst
        return licenses




from setuptools import setup
__version__ = 0.5

setup(
    name='licenses',
    version=__version__,

    # general metadata
    description='Web service that lists open (http://opensource.org/, http://opendefinition.org/) licenses',
    long_description='''
Todo: More about purpose of package.
Todo: More about installing package (easy_install licenses).
Todo: More about linking data at build-time (import licenses; print License().get_group_licenses('all_alphabetical')).
Todo: More about deploying package as a service (licenses-deploy DEST FQDN).
Todo: More about linking data at run-time (easy_install licenseservice; import ...).
    ''',
    license='PD',
    author='Open Knowledge Foundation',
    author_email='info@okfn.org',
    url='http://www.knowledgeforge.net/okfn/licenses/',
    packages=['licenses'],
    scripts=['licenses-deploy-level1', 'licenses-deploy-level2'],
    include_package_data = True,
    package_data = {
        '': ['licenses.db'],
    },
    zip_safe= False,
)
